import { Component } from '@angular/core';
import { FormGroup, FormArray, Validators, FormBuilder, ReactiveFormsModule, FormControl } from '@angular/forms';
import { TeamService } from './team.service';
import { CommonModule } from '@angular/common';

@Component({
	selector: 'app-team',
	standalone: true,
	imports: [
		CommonModule,
		ReactiveFormsModule
	],
	templateUrl: './team.component.html'
})
export class TeamComponent {
	formSubmitted = false;
	constructor(
		private formBuilder: FormBuilder,
		private teamService: TeamService) {
	}
	teamForm: FormGroup = this.formBuilder.group({
		teamName: ['', Validators.required],
		employees: this.formBuilder.array([
			new FormControl('', [Validators.required]),
			new FormControl('', [Validators.required])
		])
	});

	get employees(): FormArray {
		return this.teamForm.get('employees') as FormArray;
	}

	onFormSubmit() {
		this.teamService.saveTeam(this.teamForm.value);
		this.formSubmitted = true;
		this.teamForm.reset();
	}

	markPristine() {
		this.teamForm.get('teamName')?.markAsPristine();
		this.teamForm.get('employees')?.markAsPristine();
		//this.teamForm.markAsPristine();
		this.formSubmitted = false;
	}
}